﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Windows.Threading;
using Infragistics.Windows.DataPresenter;

namespace GroupByUpdating
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        Random _random = new Random();
        string[] groups = new string[] { "Group1", "Group2", "Group3", "Group4", "Group5", "Group6", "Group7", null, null };

        public MainWindow()
        {
            InitializeComponent();
            Loaded += MainWindow_Loaded;
        }

        void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            DispatcherTimer timer = new DispatcherTimer();
            timer.Interval = TimeSpan.FromSeconds(0.1);
            timer.Tick += timer_Tick;
            timer.Start();
        }

        void timer_Tick(object sender, EventArgs e)
        {
            SampleData sd = LayoutRoot.Resources["SampleData"] as SampleData;
            int itemIndex = _random.Next(0, sd.Count);
            int groupIndex = _random.Next(0, groups.Length);
            sd[itemIndex].name = groups[groupIndex];
        }

        private void XamDataGrid_InitializeRecord(object sender, Infragistics.Windows.DataPresenter.Events.InitializeRecordEventArgs e)
        {
            // this will be true when the record's value is changed by the timer above.  The sort position needs to be refreshed
            // when this happens or else the record will not move to the correct group.
            if (e.SortValueChanged)
                e.Record.RefreshSortPosition();
        }

        private void OnInitializeRecordDirect(object sender, Infragistics.Windows.DataPresenter.Events.InitializeRecordEventArgs e)
        {
            if (e.SortValueChanged || !e.ReInitialize)
            {
                e.Record.RefreshSortPosition();
            }
        }
    }

    public class SampleDataItem : INotifyPropertyChanged
    {
        private string _name;
        public string name
        {
            get { return _name; }
            set
            {
                if (_name != value)
                {
                    _name = value;
                    OnPropertyChanged("name");
                }
            }
        }

        private string _department;
        public string department
        {
            get { return _department; }
            set
            {
                if (_department != value)
                {
                    _department = value;
                    OnPropertyChanged("department");
                }
            }
        }

        private double _salary;
        public double salary
        {
            get { return _salary; }
            set
            {
                if (_salary != value)
                {
                    _salary = value;
                    OnPropertyChanged("salary");
                }
            }
        }

        private string _email;
        public string email
        {
            get { return _email; }
            set
            {
                if (_email != value)
                {
                    _email = value;
                    OnPropertyChanged("email");
                }
            }
        }

        #region INotifyPropertyChanged Implementation
        public event PropertyChangedEventHandler PropertyChanged;
        protected void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
        #endregion
    }

    public class SampleData : ObservableCollection<SampleDataItem>
    {
        private Random _random = new Random();

        public SampleData()
        {
            string[] groups = new string[] { "Group1", "Group2", "Group3", "Group4", "Group5", "Group6", "Group7", };
            for (int i = 0; i < 1000; i++)
            {
                SampleDataItem item = new SampleDataItem();
                item.name = groups[_random.Next(0, groups.Length)];
                item.department = "asd";
                item.salary = 100;
                item.email = "asd";
                Add(item);
            }
        }
    }
}
